{% extends "admin/change_list.html" %}
{% load url from future %}


{% block object-tools-items %}
    <a class="btn" href="{% url 'admin:auth_user_invite' %}">Invite user</a>
    {{block.super}}
{% endblock %}
