{% load news %}
{% if categories %}
    {% for category in categories %}
        <a href="{% category_url category %}">
            {{ category }}{% if not forloop.last %},{% endif %}
        </a>
    {% endfor %}
{% endif %}
