<?xml version="1.0" encoding="UTF-8" ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
    {% load static %}
    <head>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
        <title>File added</title>
        <script src="{% static 'cms/js/tiny_mce/tiny_mce_popup.js' %}"></script>
        {% include "admin/cms/scripts.html" %}
        <script>
            tinyMCEPopup.onInit.add(function() {
                django.jQuery.cms.media.complete("{{permalink|escapejs}}", "{{title|escapejs}}");
            });
        </script>
    </head>
    <body>
    </body>
</html>
