{% extends changelist_template_parent %}
{% load static %}


{% block extrahead %}
    {{block.super}}
    {% if is_popup %}
        <script src="{% static 'cms/js/tiny_mce/tiny_mce_popup.js' %}"></script>
        {% include "admin/cms/scripts.html" %}
        <script>
            tinyMCEPopup.onInit.add(function() {
                django.jQuery.cms.media.initBrowser();
            });
        </script>
    {% endif %}
{% endblock %}
